# CHANGELOG



## v0.0.2 (2023-08-13)

### Fix

* fix: Added some initial structure to the project ([`195bfc9`](https://github.com/KennethEnevoldsen/snp-transformer/commit/195bfc99b8e27c56f5489fa3588664522fe0ffc1))

### Unknown

* Merge branch &#39;main&#39; of https://github.com/KennethEnevoldsen/snp-transformer ([`76c3580`](https://github.com/KennethEnevoldsen/snp-transformer/commit/76c3580c49b944d0a4d0ae5e036d43a911d8bb2a))


## v0.0.1 (2023-08-13)

### Build

* build: Added torch as a dependency ([`df8d64b`](https://github.com/KennethEnevoldsen/snp-transformer/commit/df8d64bfa8bdd6d49bf130f69920ba026b26bac0))

### Chore

* chore: remove boilerplate files ([`232adb9`](https://github.com/KennethEnevoldsen/snp-transformer/commit/232adb953299b9d3849043891ec38dc117fc283f))

### Ci

* ci: removed docs workflow ([`b8d0560`](https://github.com/KennethEnevoldsen/snp-transformer/commit/b8d0560809e22c33d16575092cc56debcd733aca))

### Documentation

* docs: updated docs ([`69a4222`](https://github.com/KennethEnevoldsen/snp-transformer/commit/69a42220e40db6a87f50f5b6cf9ef8027393a4d3))

### Fix

* fix: updated cruft ([`42d00d5`](https://github.com/KennethEnevoldsen/snp-transformer/commit/42d00d502acb2a76f549d00f50f47d76c20fa3f1))

### Unknown

* Merge branch &#39;main&#39; of https://github.com/KennethEnevoldsen/snp-transformer ([`cae9773`](https://github.com/KennethEnevoldsen/snp-transformer/commit/cae9773f7c55e5f9b1767e930fba7e57b4102c03))

* Merge pull request #2 from KennethEnevoldsen/dependabot/pip/invoke-2.2.0

deps:(deps-dev): bump invoke from 2.1.1 to 2.2.0 ([`2e8388f`](https://github.com/KennethEnevoldsen/snp-transformer/commit/2e8388f15f792b74a0867f2c20baac50d98e9b4e))

* Merge pull request #1 from KennethEnevoldsen/dependabot/pip/pyright-1.1.320

deps:(deps-dev): bump pyright from 1.1.305 to 1.1.320 ([`9e5421b`](https://github.com/KennethEnevoldsen/snp-transformer/commit/9e5421b181adeff52ca7a526dd3a7bb1d24c724b))

* deps:(deps-dev): bump invoke from 2.1.1 to 2.2.0

Bumps [invoke](https://github.com/pyinvoke/invoke) from 2.1.1 to 2.2.0.
- [Commits](https://github.com/pyinvoke/invoke/compare/2.1.1...2.2.0)

---
updated-dependencies:
- dependency-name: invoke
  dependency-type: direct:production
  update-type: version-update:semver-minor
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`068e048`](https://github.com/KennethEnevoldsen/snp-transformer/commit/068e048847091decb4255dbd3ba2bfb96cefa4ea))

* deps:(deps-dev): bump pyright from 1.1.305 to 1.1.320

Bumps [pyright](https://github.com/RobertCraigie/pyright-python) from 1.1.305 to 1.1.320.
- [Release notes](https://github.com/RobertCraigie/pyright-python/releases)
- [Commits](https://github.com/RobertCraigie/pyright-python/compare/v1.1.305...v1.1.320)

---
updated-dependencies:
- dependency-name: pyright
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`6497fa5`](https://github.com/KennethEnevoldsen/snp-transformer/commit/6497fa5b5c281105e58ec1eac529178c1de465d5))

* updated readme ([`0adad5a`](https://github.com/KennethEnevoldsen/snp-transformer/commit/0adad5a0162d5ea79a3c946023c4feb6aebd8229))

* updated readme ([`19033f0`](https://github.com/KennethEnevoldsen/snp-transformer/commit/19033f0ff8d1ccc317996549a2e3ea67f7f5c3cb))

* initial commit ([`9c5d964`](https://github.com/KennethEnevoldsen/snp-transformer/commit/9c5d964b70a04e05cb035a3479a2441e3691ea02))
